==> solidity.solidity-parser-antlr-0.1.1.tgz: package/es/tests/index.test.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import { Code } from 'astql';
import fs from 'fs';
import path from 'path';
import codeExample from './codeExample.js';
var code = new Code('file.solidity', codeExample, {
  parser: require('../index.js').default
});
it('code should parse without error', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
  return _regeneratorRuntime.wrap(function _callee$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          _context.next = 2;
          return code.parse();

        case 2:
          expect(code.ast).toHaveProperty('_type');

        case 3:
        case "end":
          return _context.stop();
      }
    }
  }, _callee);
})));
it('ast.getFullText() should match codeExample.txt', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
  return _regeneratorRuntime.wrap(function _callee2$(_context2) {
    while (1) {
      switch (_context2.prev = _context2.next) {
        case 0:
          expect(code.ast.getFullText()).toMatchSnapshot();

        case 1:
        case "end":
          return _context2.stop();
      }
    }
  }, _callee2);
})));
it('should query generated ast', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
  var result;
  return _regeneratorRuntime.wrap(function _callee3$(_context3) {
    while (1) {
      switch (_context3.prev = _context3.next) {
        case 0:
          _context3.next = 2;
          return code.query('*');

        case 2:
          result = _context3.sent;
          expect(result.length).not.toBe(0);
          expect(result.length).toMatchSnapshot();

        case 5:
        case "end":
          return _context3.stop();
      }
    }
  }, _callee3);
})));

==> solidity.solidity-parser-antlr-0.1.2.tgz: package/es/tests/index.test.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import { Code } from '@astql/core';
import fs from 'fs';
import path from 'path';
import codeExample from './codeExample.js';
var code = new Code('file.solidity', codeExample, {
  parser: require('../index.js')["default"]
});
it('code should parse without error', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
  return _regeneratorRuntime.wrap(function _callee$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          _context.next = 2;
          return code.parse();

        case 2:
          expect(code.ast).toHaveProperty('_type');

        case 3:
        case "end":
          return _context.stop();
      }
    }
  }, _callee);
})));
it('ast.getFullText() should match codeExample.txt', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
  return _regeneratorRuntime.wrap(function _callee2$(_context2) {
    while (1) {
      switch (_context2.prev = _context2.next) {
        case 0:
          expect(code.ast.getFullText()).toMatchSnapshot();

        case 1:
        case "end":
          return _context2.stop();
      }
    }
  }, _callee2);
})));
it('should query generated ast', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
  var result;
  return _regeneratorRuntime.wrap(function _callee3$(_context3) {
    while (1) {
      switch (_context3.prev = _context3.next) {
        case 0:
          _context3.next = 2;
          return code.query('*');

        case 2:
          result = _context3.sent;
          expect(result.length).not.toBe(0);
          expect(result.length).toMatchSnapshot();

        case 5:
        case "end":
          return _context3.stop();
      }
    }
  }, _callee3);
})));
